@@ -30,6 +30,19 @@
 #endif /* IO_BASE */
 #define IO_SIZE (1024*1024*128)
 
+#define GPIO_BASE (IO_BASE + 0x200000)
+#define UART_BASE (GPIO_BASE + 0x1000)
+
+/** Triggered when the PL011 asserts IRQ status */
+#define UART0_IRQ 57
+
+/** PhysicalTimer1, IRQ number. */
+#define ARMTIMER_IRQ 3
+
+#define RAM_ADDR (0x0)
+#define RAM_SIZE (1024 * 1024 * 512)
+#define TMPSTACKADDR (RAM_ADDR + (1024 * 1024 * 32))
+
 #include <arm/ARMConstant.h>
 
 #ifndef __HOST__
