@@ -16,6 +16,7 @@
  */
 
 #include <Log.h>
+#include <FreeNOS/ProcessManager.h>
 #include "PrivExec.h"
 
 API::Result PrivExecHandler(PrivOperation op, Address addr)
@@ -27,14 +28,8 @@ API::Result PrivExecHandler(PrivOperation op, Address addr)
     case Idle: {
         ProcessManager *procs = Kernel::instance->getProcessManager();
         procs->setIdle(procs->current());
-#ifdef INTEL
-        irq_enable();
-
-        while (true)
-            idle();
-#endif /* INTEL */
-        }
         return API::Success;
+    }
 
     case Reboot:
         cpu_reboot();
