@@ -60,9 +60,23 @@ class Allocator
     };
 
     /**
-     * Class constructor.
+     * Describes a range of memory.
      */
-    Allocator();
+    typedef struct Range
+    {
+        Address address; /**< Starting address of the memory range. */
+        Size size;       /**< Amount of memory in bytes. */
+        Size alignment;  /**< Alignment in bytes or ZERO for default alignment. */
+    } Range;
+
+  public:
+
+    /**
+     * Class constructor.
+     *
+     * @param range Block of continguous memory to manage.
+     */
+    Allocator(const Range range);
 
     /**
      * Class destructor.
@@ -91,54 +105,49 @@ class Allocator
     void setParent(Allocator *parent);
 
     /**
-     * Set allocation alignment.
+     * Get parent Allocator
      *
-     * Configure the Allocator such that each allocated
-     * address must be aligned to the given size.
-     *
-     * @param size Alignment size
-     *
-     * @return Result code
+     * @return Pointer to parent Allocator instance or NULL if none.
      */
-    Result setAlignment(Size size);
-
-    /**
-     * Set allocation base.
-     *
-     * The allocation base will be added to each allocation.
-     *
-     * @param addr Allocation base address.
-     *
-     * @return Result code
-     */
-    Result setBase(Address addr);
+    Allocator * parent();
 
     /**
      * Get memory size.
      *
      * @return Size of memory owned by the Allocator.
      */
-    virtual Size size() const = 0;
+    Size size() const;
+
+    /**
+     * Get memory base address for allocations.
+     *
+     * @return Memory address used as base address
+     */
+    Address base() const;
+
+    /**
+     * Get memory alignment in bytes for allocations.
+     *
+     * @return Memory alignment value in bytes
+     */
+    Size alignment() const;
 
     /**
      * Get memory available.
      *
      * @return Size of memory available by the Allocator.
      */
-    virtual Size available() const = 0;
+    virtual Size available() const;
 
     /**
      * Allocate memory.
      *
-     * @param size Amount of memory in bytes to allocate on input.
-     *             On output, the amount of memory in bytes actually allocated.
-     * @param addr Output parameter which contains the address
-     *             allocated on success.
-     * @param align Alignment of the required memory or use ZERO for default.
+     * @param args Contains the requested size and alignment on input.
+     *             On output, contains the actual allocated address.
      *
      * @return Result value.
      */
-    virtual Result allocate(Size *size, Address *addr, Size align = ZERO) = 0;
+    virtual Result allocate(Range & args);
 
     /**
      * Release memory.
@@ -149,7 +158,7 @@ class Allocator
      *
      * @see allocate
      */
-    virtual Result release(Address addr) = 0;
+    virtual Result release(const Address addr);
 
   protected:
 
@@ -164,23 +173,18 @@ class Allocator
      *
      * @return Aligned Address.
      */
-    Address aligned(Address addr, Size boundary) const;
-
-  protected:
-
-    /** Our parent Allocator, if any. */
-    Allocator *m_parent;
-
-    /** Allocation memory alignment. */
-    Size m_alignment;
-
-    /** Allocation base address */
-    Address m_base;
+    Address aligned(const Address addr, const Size boundary) const;
 
   private:
 
     /** Points to the default Allocator for new()/delete(). */
-    static Allocator *m_default; 
+    static Allocator *m_default;
+
+    /** Our parent Allocator, if any. */
+    Allocator *m_parent;
+
+    /** Range of memory that this Allocator manages */
+    Range m_range;
 };
 
 #ifndef __HOST__
@@ -197,10 +201,13 @@ class Allocator
  */
 inline void * operator new(__SIZE_TYPE__ sz)
 {
-    Address addr;
+    Allocator::Range alloc_args;
 
-    if (Allocator::getDefault()->allocate((Size *) &sz, &addr) == Allocator::Success)
-        return (void *) addr;
+    alloc_args.size = sz;
+    alloc_args.alignment = 0;
+
+    if (Allocator::getDefault()->allocate(alloc_args) == Allocator::Success)
+        return (void *) alloc_args.address;
     else
         return (void *) NULL;
 }
@@ -212,10 +219,13 @@ inline void * operator new(__SIZE_TYPE__ sz)
  */
 inline void * operator new[](__SIZE_TYPE__ sz)
 {
-    Address addr;
+    Allocator::Range alloc_args;
 
-    if (Allocator::getDefault()->allocate((Size *) &sz, &addr) == Allocator::Success)
-        return (void *) addr;
+    alloc_args.size = sz;
+    alloc_args.alignment = 0;
+
+    if (Allocator::getDefault()->allocate(alloc_args) == Allocator::Success)
+        return (void *) alloc_args.address;
     else
         return (void *) NULL;
 }
