@@ -15,27 +15,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <FreeNOS/System.h>
 #include "PoolAllocator.h"
 #include <MemoryBlock.h>
 
-PoolAllocator::PoolAllocator()
-    : Allocator()
+PoolAllocator::PoolAllocator(const Allocator::Range range)
+    : Allocator(range)
 {
     MemoryBlock::set(m_pools, 0, sizeof(m_pools));
 }
 
-Size PoolAllocator::size() const
-{
-    return m_parent ? m_parent->size() : ZERO;
-}
-
-Size PoolAllocator::available() const
-{
-    return m_parent ? m_parent->available() : ZERO;
-}
-
-Allocator::Result PoolAllocator::allocate(Size *size, Address *addr, Size align)
+Allocator::Result PoolAllocator::allocate(Allocator::Range & args)
 {
     Size index, nPools = 1;
     MemoryPool *pool = ZERO;
@@ -43,13 +32,13 @@ Allocator::Result PoolAllocator::allocate(Size *size, Address *addr, Size align)
     // Find the correct pool size
     for (index = POOL_MIN_POWER; index < POOL_MAX_POWER; index++)
     {
-        if (*size <= (Size) 1 << (index + 1)) break;
+        if (args.size <= (Size) 1 << (index + 1)) break;
     }
 
     // Do we need to allocate an initial pool?
-    if (!m_pools[index] && m_parent)
+    if (!m_pools[index] && parent())
     {
-        pool = m_pools[index] = newPool(index, POOL_MIN_COUNT(*size));
+        pool = m_pools[index] = newPool(index, POOL_MIN_COUNT(args.size));
     }
     // Search for pool with enough memory
     else
@@ -64,7 +53,7 @@ Allocator::Result PoolAllocator::allocate(Size *size, Address *addr, Size align)
             // If no pool has free space anymore, allocate another
             if (!pool->next)
             {
-                pool = newPool(index, POOL_MIN_COUNT(*size) * nPools);
+                pool = newPool(index, POOL_MIN_COUNT(args.size) * nPools);
                 break;
             }
         }
@@ -72,29 +61,32 @@ Allocator::Result PoolAllocator::allocate(Size *size, Address *addr, Size align)
     // Attempt to allocate
     if (pool)
     {
-        *addr = pool->allocate();
+        args.address = pool->allocate();
         return Success;
     }
-    *addr = ZERO;
+    args.address = ZERO;
     return OutOfMemory;
 }
 
 MemoryPool * PoolAllocator::newPool(Size index, Size cnt)
 {
     MemoryPool *pool = 0;
-    Size sz;
+    Allocator::Range alloc_args;
 
     // Prepare amount to allocate from m_parent
-    sz  = cnt * (1 << (index + 1));
-    sz += sizeof(MemoryPool);
-    sz += BITMAP_NUM_BYTES(cnt);
-    sz += MEMALIGN;
+    alloc_args.address = 0;
+    alloc_args.alignment = 0;
+    alloc_args.size  = cnt * (1 << (index + 1));
+    alloc_args.size += sizeof(MemoryPool);
+    alloc_args.size += BITMAP_NUM_BYTES(cnt);
+    alloc_args.size += alignment();
 
     // Ask m_parent for memory, then fill in the pool
-    if (m_parent->allocate(&sz, (Address *)&pool) == Success)
+    if (parent()->allocate(alloc_args) == Allocator::Success)
     {
+        pool = (MemoryPool *) alloc_args.address;
         pool->count  = cnt;
-        pool->addr   = aligned( ((Address) (pool + 1)) + BITMAP_NUM_BYTES(pool->count), MEMALIGN );
+        pool->addr   = aligned( ((Address) (pool + 1)) + BITMAP_NUM_BYTES(pool->count), alignment() );
         pool->next   = m_pools[index];
         pool->free   = pool->count;
         pool->size   = (1 << (index + 1));
@@ -104,7 +96,7 @@ MemoryPool * PoolAllocator::newPool(Size index, Size cnt)
     return pool;
 }
 
-Allocator::Result PoolAllocator::release(Address addr)
+Allocator::Result PoolAllocator::release(const Address addr)
 {
     for (Size i = POOL_MIN_POWER - 1; i < POOL_MAX_POWER; i++)
     {
